#!/bin/bash
#
# file: install.sh part of FLAC-JACKET - FLAC Audio Management Program
# install script
##
#    Copyright 2004, 2005 Pete Nesbitt (pete@linux1.ca)
#
#    This file is part of Flac-Jacket.
#
#    Flac-Jacket is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Flac-Jacket is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flac-Jacket; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##


# first, lets be sure we were run locally
if [ $0 != "./install.sh" ]; then
   PATH_HERE="`echo $0 | sed s/install.sh//`"
   clear
   echo ""
   echo " !!FLAC-JACKET Installation Error!!"
   echo ""
   echo " ERROR: The Flac-Jacket install script must be run from its local directory."
   echo " Change directories to $PATH_HERE and run:"
   echo " ./install.sh"
   echo ""
   exit 1
fi

VERSION="1.0"
LOGO="images/fjacket.png"
BKG_IMG="images/bkg_grn-bar2.jpg"

. src/install_libs

# set a few defaults to get started
# source  dir (should be current)
TOP_DIR="$PWD"
# Where to install
if [ $UID -gt 99 ]; then
 DEFAULT_DEST_DIR="${HOME}/fjacket-${VERSION}"
 DEFAULT_BASE_DIR="${HOME}/music"
 INTRO_MSG()
  {
  echo " If you continue:"
  echo "  A) The directory containing your music, both raw and flac files,"
  echo "     will be writable only by you, and usually only accessible to you."
  echo "  B) The default install directory is ${DEFAULT_DEST_DIR}."
  echo "     This can be changed during the installlation."
  }
else
 DEFAULT_DEST_DIR="/usr/local/fjacket-${VERSION}"
 DEFAULT_BASE_DIR="/music"
 INTRO_MSG()
  {
  echo " If you continue:"
  echo "  A) The directory containing your music, both raw and flac files,"
  echo "     will be 'World Writable' so that other users can run Flack-Jacket."
  echo "  B) The default install directory is ${DEFAULT_DEST_DIR}."
  echo "     This can be changed during the installlation."
  }
fi

DEST_DIR="not_set"

# where to store the music
BASE_DIR="not_set"

# where to look for the .raw files
# is set below based on resolved BASE_DIR
RAW_DIR="not_set"


# the source files
BASE_RC="src/base_rc"
BUILD_RC="src/build_rc"
BUILD2_RC="src/build2_rc"
BUILD2out_RC="src/build2out_rc"
FJACKET_P1="src/fjacket.sh_p1"
FJACKET_P2="src/fjacket.sh_p2"

## print nice screen
print_INSTALL_SCREEN
#########################

# a few instructions:
echo " We need to gather some information before starting."
echo ""
echo " In the following screens, you will be asked a few questions."
echo " To accept the default selection, press 'Y', 'y' or press [ENTER]"
echo " press any other key to change the action, or Ctrl-C to quit."
echo ""
echo " This program can be installed as the ROOT user or as a regular user."
echo " Typically, when installed as root, the application is available to all users,"
echo " and if installed by a regular user, only that user can access the program."
echo ""
echo -e '\E[33m'
echo -n " You are installing as user:  "
echo -e -n '\E[31m'
echo -n "$USER"
echo -e '\E[33m'

INTRO_MSG
echo ""
tput sgr0
echo ""

START_QUESTIONS="Y"
printf "   => Begin? [$START_QUESTIONS]"
read START_QUESTIONS
   if [ "$START_QUESTIONS" = "" ]; then
      START_QUESTIONS="Y"
   fi
   if [ "$START_QUESTIONS" != "Y" ] && [ "$START_QUESTIONS" != "y" ] ; then
     echo ""
     echo " Installation aborted!!"
     echo " done"
     exit 0
   else
     echo ""
     echo " Continuing with Installation..."
     echo ""
     echo ""
     sleep 1
     # reprint screen
     print_INSTALL_SCREEN
   fi


# get some directory locations (write to rc)
#
# get the installation location, returned as DEST_DIR
prompt_DIR DEST

# where the config file should be built
RC="${DEST_DIR}/flac_jacket.rc"

# reprint screen
print_INSTALL_SCREEN

# get the base music location
prompt_DIR BASE

# reprint screen
print_INSTALL_SCREEN

# get the .raw location
prompt_DIR RAW

# reprint screen
print_INSTALL_SCREEN

# check if we should be creating a symlink
prompt_SYM




# reprint screen
print_INSTALL_SCREEN
#########################

###
# a bailout point.

PROCEED_OK="Y"
echo ""
echo " Ready to Install Flac-Jacket"
echo "Install directory:  $DEST_DIR"
echo ""
echo "Music directory is at:  $BASE_DIR"
echo "We will seek Raw Audio files (.raw) in  $RAW_DIR"
echo ""
echo "Please read Important Information displayed after installation completes."
echo ""
echo ""
printf "   => Continue? [${PROCEED_OK}]"
read PROCEED_OK
   if [ "$PROCEED_OK" = "" ]; then
      PROCEED_OK="Y"
   fi
   if [ "$PROCEED_OK" != "Y" ] && [ "$PROCEED_OK" != "y" ] ; then
     echo ""
     echo " Installation aborted!!"
     echo " done"
     exit 0
   else
     echo ""
     echo " Continuing with Installation..."
     echo ""
     echo ""
   fi

###

# check that we have all required support files
echo " Checking for required system files..."
get_CHK_REQUIRED
echo " Done."

# add the last bit to the rc file
echo ""
echo  -n " Making final configuration updates..."
echo "" >> $RC
echo "# This should be okay on most Linux distos," >> $RC
echo "# but the format string may need adjustment on Solaris or BSD (?)" >> $RC
echo 'TODAY="`$DATE +%y-%m-%d-%H-%M`"' >> $RC
echo "" >> $RC
echo " Done"
echo ""
##


# copy files to new dir
# do we have write permission?
echo ""
echo -n "checking that we can write to ${DEST_DIR}..." 
touch ${DEST_DIR}/test > /dev/null 2>&1
  if [ $? -eq 0 ]; then
     rm ${DEST_DIR}/test
      if [ $? -eq 0 ]; then
        echo "  OK"
        cp -p -r `ls|egrep -v "src|INSTALL|install.sh"` ${DEST_DIR}/ > /dev/null 2>&1        
        if [ $? -eq 0 ]; then
           echo " All files copied successfuly"
        else
          echo " ERROR: failed copying files into $DEST_DIR "
          echo " Possible disk space problem?"
          echo " Check that destination is writeable and run install again."
          exit 1
        fi 
      fi
  else
      echo " ERROR: cannot copy files into $DEST_DIR "
      echo " please check that you have write access."
      echo " and run install again"
      exit 1
  fi

echo ""
# creat a dir for web page related images
echo ""
IMAGES_DIR=${BASE_DIR}/images
echo -n "creating and populating $IMAGES_DIR for web images..."
if [ ! -e $IMAGES_DIR ]; then
   mkdir $IMAGES_DIR > /dev/null 2>&1
      if [ $? -eq 0 ]; then
         put_WEBIMAGES
      else
        echo "  ERROR!"
        echo "  Could not create ${IMAGES_DIR},"
        echo "  You will need to manually create it,"
        echo "  or manually edit ${DEST_DIR}/${CSS}."
      fi
elif [ -e ${IMAGES_DIR} ] && [ -d ${IMAGES_DIR} ]; then
      put_WEBIMAGES
elif [ -e ${IMAGES_DIR} ] && [ ! -d ${IMAGES_DIR} ]; then
     echo "  WARNING!"
     echo "  a file exists called ${IMAGES_DIR},"
     echo "  You will need to remove or rename it, or else,"
     echo "  Make an alternate dir for web images, then copy both"
     echo "  ${DEST_DIR}/${LOGO} and  ${DEST_DIR}/${BKG_IMG} into it, and"
     echo "  manually edit ${DEST_DIR}/${CSS} to show new images location."
     echo ""
     echo "  Things will still work, but the web page may be drag :("
else
     echo "  ERROR!"
     echo "  Could not create ${BASE_DIR}/images, possible permission problem?"
     echo "  the html page may be a little drab :("
fi

# copy the css into the music dir (BASE_DIR)
echo ""
echo -n "copying Style Sheet into ${BASE_DIR}..."
    cp -f ${DEST_DIR}/flac_jacket.css ${BASE_DIR}/ > /dev/null 2>&1
    if [ $? -eq 0 ]; then
       echo "  OK"
    else
       echo "  Warning!"
       echo "  Could not copy Style Sheet into ${BASE_DIR},"
       echo "    the html page may be a little drab :("
    fi

# build some files based on gathered information
echo ""
# first flac_jacket.rc from base_rc build_rc build2_rc
echo -n "building 'flac_jacket.rc' resources file..."
cd $DEST_DIR > /dev/null 2>&1
   if [ $? -ne 0 ]; then
      echo "    ERROR!!!"
      echo " Failed to change to $DEST_DIR"
      echo " Please check that you have access to that directory"
      echo ""
      exit 1
   else
# assemble the rc file from base_rc build_rc build2_rc
      cat ${TOP_DIR}/${BASE_RC} > flac_jacket.rc
      echo -n " VERSION="  >> flac_jacket.rc
      echo $VERSION  >> flac_jacket.rc
#      echo -n " LOGO="  >> flac_jacket.rc
#      echo ${DEST_DIR}/${LOGO}  >> flac_jacket.rc
      echo ""  >> flac_jacket.rc
      echo "###############################################" >> flac_jacket.rc
      echo "## YOU WILL PROBABLY WANT TO EDIT THE FOLLOWING" >> flac_jacket.rc
      echo "#" >> flac_jacket.rc
      echo "" >> flac_jacket.rc
      echo "#Were the music (flac) albums dir starts. This directory must already exist," >> flac_jacket.rc
      echo " # but the script will create all the artist/album subdirectories as required." >> flac_jacket.rc
      echo " #this directory would typically just have artist directories" >> flac_jacket.rc
      echo "### CHANGE THIS TO WHERE YOUR OUTPUTED FLAC FILES WILL BE STORED (.flac)" >> flac_jacket.rc
      echo ' # BASE_DIR="/data/media/music/albums"' >> flac_jacket.rc
      echo -n "  BASE_DIR=" >> flac_jacket.rc
      echo $BASE_DIR >> flac_jacket.rc
      echo "" >> flac_jacket.rc
      echo "#where you stored the raw audio files  (dir conatins .raw files)" >> flac_jacket.rc
      echo "### CHANGE THESE TO WHERE YOU WILL SAVE RAW AUDIO FILES (.raw)" >> flac_jacket.rc
      echo -n " RAW_DIR=" >> flac_jacket.rc
      echo $RAW_DIR >> flac_jacket.rc
      # need to extract the short name ??
      RAW_DIR_SHORT="`echo $RAW_DIR |sed 's/[a-zA-Z0-9_-]\+\///g'|cut -d/ -f2`"
      echo -n " RAW_DIR_SHORT=" >> flac_jacket.rc
      echo -n $RAW_DIR_SHORT >> flac_jacket.rc
      echo "  # just the dir name, not the full path." >> flac_jacket.rc
      cat ${TOP_DIR}/${BUILD_RC} >> flac_jacket.rc
      cat ${TOP_DIR}/${BUILD2out_RC} >> flac_jacket.rc
      echo " Done."
# done with the rc      

# assemble fjacket.sh from $FJACKET_P1, _p2.sh  & _p2.sh
# save the install dir as a hardcode in the main script,
# so that it can be called from where ever.
      echo ""
      echo ""
      echo -n "building 'fjacket.sh' start script..."
      cat ${TOP_DIR}/${FJACKET_P1} > fjacket.sh
      echo "# This is the dirctory where Flac-Jacket was installed:" >> fjacket.sh
      echo -n "# " >> fjacket.sh
      echo $PWD >> fjacket.sh
      echo "# lets make sure we start from there" >> fjacket.sh
      echo -n "cd " >> fjacket.sh
      echo -n $DEST_DIR >> fjacket.sh
      echo " > /dev/null 2>&1" >> fjacket.sh
      echo '  if [ $? -ne 0 ]; then' >> fjacket.sh
      echo '     echo "    ERROR!!!"'  >> fjacket.sh
      echo -n '     echo "   Failed to change to ' >> fjacket.sh
      echo  "${DEST_DIR}\"" >> fjacket.sh
      echo '     echo "   Please check the fjacket.sh and correct"' >> fjacket.sh
      echo '     echo "   the path to the install directory near line 40"' >> fjacket.sh
      echo '     exit 1' >> fjacket.sh
      echo '  fi' >> fjacket.sh
      cat ${TOP_DIR}/${FJACKET_P2} >> fjacket.sh
      echo " Done."
  fi
#done with the start script

#return to install area.
cd $TOP_DIR
######


# set ownership and check permissions (execute on all scripts)
echo ""
# OWNERSHIP
echo -n " setting file ownership..."
 if [ $UID -gt 99 ]; then
    echo -n " owner = $USER "
    chown -R ${USER}:${GID} ${DEST_DIR} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
       echo "   Success"
    else
       echo " ERROR"
       echo ""
       echo " ERROR: cannot set ownership to user $USER"
       echo " please check permissions on parent directory,"
       echo " and run install again"
       exit 1

    fi
 else
    echo -n " you're too powerful (root?), so lets use 'nobody' "
    chown -R nobody:nobody ${DEST_DIR} > /dev/null 2>&1
    if [ $? -eq 0 ]; then
        echo "   Success"
        echo ""
        echo -n " allowing everyone write access for usability "
        chmod -R a+w ${BASE_DIR} > /dev/null 2>&1
         if [ $? -eq 0 ]; then
            echo "   Success"
         else
            echo " ERROR"
            echo ""
            echo " ERROR: cannot set ownership to allow all users write access to"
            echo "     ${BASE_DIR}."
            echo " You should set that manually after install or regular users will"
            echo " not be able to run Flac-Jacket." 
            #let user read message
            echo ""
            STEP_DONE="wait"
            printf "   => Press [ENTER] to Continue"
            read STEP_DONE
            unset STEP_DONE 
         fi
    else
        echo " ERROR"
        echo ""
        echo " ERROR: cannot set file ownership to 'nobody' "
        echo " lets try to use your real id..."
        BASE_ID="`who am i|cut -d' ' -f1`"
        BASE_GROUP="`groups $BASE_ID|cut -d' ' -f3`"
        chown -R ${BASE_ID}:${BASE_GROUP} ${DEST_DIR} > /dev/null 2>&1
          if [ $? -eq 0 ]; then
             echo "   Success"
          else
             echo " ERROR"
             echo ""
             echo " ERROR: cannot set ownership to user $USER"
             echo " please check permissions on parent directory,"
             echo " and run install again"
             exit 1
          fi 
    fi
 fi

echo ""
# READ access on all files
echo -n " setting file read permissions..."
chmod a+r ${DEST_DIR}/* > /dev/null 2>&1
  if [ $? -eq 0 ]; then
     echo "   Success"
     echo ""
  else
     echo " ERROR"
     echo ""
     echo " ERROR: cannot set file permissions in $DEST_DIR "
     echo " please check that you have write access."
     echo " and run install again"
     exit 1
  fi

# EXECUTE on scripts
echo -n " setting executable file permissions..."
chmod 755 ${DEST_DIR}/*.sh > /dev/null 2>&1
  if [ $? -eq 0 ]; then
     echo "   Success"
        # make sym link
        make_SYM
  else
      echo " ERROR"
      echo ""
      echo " ERROR: cannot set file permissions in $DEST_DIR "
      echo " please check that you have write access."
      echo " and run install again"
      exit 1
  fi


#####
# report successful install
echo -e '\E[37;44m'
echo "                                                                    "
echo " ****************************************************************** "
echo "           Flac-Jacket Installation completed successfully!         "
echo " ****************************************************************** "
echo "                                                                    "
echo "  You should review the settings in ${RC}                           "
echo "                                                                    "
echo "  Be sure to read the IMPORTANT Filename Format Information         "
echo "  in the OVERVIEW file (Item #5) before running Flac-Jacket.        "
echo "                                                                    "
echo "  To run Flac-Jacket (if a symlink was created in your PATH),       "
echo "  enter 'fjacket' at the command line.                              "
echo "  Otherwise, you'll need to enter ${DEST_DIR}/fjacket.sh            "
echo "                                                                    "
echo "  You can safely remove \"${PWD}\" source directory.                "
echo "  To Uninstall Flac-Jacket simply remove the $DEST_DIR directory,   "
echo "   and delete the symlink if you chose to create one.               "
echo "                                                                    "
echo "                                                                    "
echo " ****************************************************************** "
echo "                                                                    "
tput sgr0
echo ""
# unset the locally used vars
unset TOP_DIR DEST_DIR MANUAL_UPDATES RC THIS_CMD_VAR THIS_CMD_NAME THIS_VARPATH THIS_CMD_PATH 
unset DEST_DIR DIR_OK MAKEDIR NEWDIR_OK ISCMD line LINK_NAME VERSION LOGO BKG_IMG IMAGES_DIR

