#!/bin/bash
#
# file name: make_html.sh part of FLAC-JACKET - FLAC Audio Management Program
# script to create a playlist of FLAC audio recordings within an html page.

##
#    Copyright 2004, 2005 Pete Nesbitt (pete@linux1.ca)
#
#    This file is part of Flac-Jacket.
#
#    Flac-Jacket is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Flac-Jacket is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flac-Jacket; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##

############ HOW TO MODIFY THE HTML PAGE
# You can easily change the appearance of the html output file by editing
# the **CSS FILE ** named "flac_jacket.css". You may also want to edit 
# different sections of this file. The main assembly of all the html bits
# is the END SECTION of THIS FILE, look there to start.
# I think it's fairly well commented so it should be simple to modify.
############

#  ## IMPORTANT ##
# variables are in the rc file
# YOU WILL PROBABLY NEED TO EDIT THE FOLLOWING FILE:
. flac_jacket.rc


# get the directory listing into a file
# set each file line to be a url
##################################

# first enter each artists dir, then retreive each recording
cd $BASE_DIR
# for url
$LS -1  > $LIST_ARTISTS

## added Mar 2005 to add a bit of simple navigation (page is getting very long)
# get each artist name for top of page summary/links
$ECHO "<table border=0 cellpadding=6 width='100%'><tr>" > $ARTISTS_SUMMARY
COL="0"
while read ARTIST
 do
  # ignore: anything that is not a directory containing .flac files
  if [ -d $ARTIST ] && [ "`$LS -1 ${ARTIST}/|$GREP \"\.flac$\"`" != "" ]; then
   COL=`$ECHO "$COL + 1"| $BC`
     if [ $COL -ge 4 ] ; then
       COL="1"
       $ECHO "</tr><tr>" >> $ARTISTS_SUMMARY
     fi

   $ECHO "<td><a href=#${ARTIST}>`$ECHO $ARTIST | $SED -e s/"_"/" "/g`</a></td>" >> $ARTISTS_SUMMARY
  fi
 done < $LIST_ARTISTS
$ECHO "</tr></table>" >> $ARTISTS_SUMMARY
# continue with page build
############


$ECHO "<table border=0 cellpadding=5><tr><td>" > $LIST_FILE
# enter each artist-dir and get album list (output 
while read ARTIST_NAME
 do
   # ignore: anything that is not a directory containing .flac files
   if [ -d $ARTIST_NAME ] && [ "`$LS -1 ${ARTIST_NAME}/|$GREP \"\.flac$\"`" != "" ]; then
   cd $ARTIST_NAME
     # clear out any info saved from last artist
     $RM -f $LIST_SELECTION_BEG $LIST_SELECTION_END > /dev/null 2>&1
     $ECHO "<tr><td colspan=3>" >> $LIST_FILE
     # add a link from top artist list
     $ECHO "<a name=$ARTIST_NAME><hr></a><b><u>`$ECHO $ARTIST_NAME | $SED -e s/"_"/" "/g`</u></b><br>" >> $LIST_FILE
     $ECHO "</td></tr>" >> $LIST_FILE
     #work on each album tile. using ^ as a temp field separator, should be safe.
     $LS -1 *.flac | $AWK -F- '{print $2"^"$1}'| $SED -e s/"_"/"^"/|$AWK -F^ '{print $1"-"$3"-"$2}'|$SORT > $LIST_SELECTION_A
      #must adjust sort list so 00 to 20 are at end of list
      while read line
       do
         YEAR_BASE="`$EXPR \`$ECHO $line|$CUT -d- -f1\` \* 1`"
         if [ $YEAR_BASE -le 20 ]; then
            echo $line >> $LIST_SELECTION_END
         else
            echo $line >> $LIST_SELECTION_BEG
         fi
       done < $LIST_SELECTION_A
       $CAT $LIST_SELECTION_BEG $LIST_SELECTION_END 2>/dev/null |$AWK -F- '{print $2"-"$1"_"$3}' > $LIST_SELECTION 
     
       while read ALBUM
        do
          SHORT_NAME="${ALBUM%%.flac}"
          SIDE_NUM=`$ECHO $SHORT_NAME | $AWK -F- '{print $2}' | $AWK -F_ '{print $2}'`
          YEAR=`$ECHO $SHORT_NAME | $AWK -F- '{print $2}' | $AWK -F_ '{print $1}'`
           #most likely century, if YEAR less than 20, use 2000, else 1900 (added May 2005)
           if [ $YEAR -le 20 ];then
              FULLYEAR="20${YEAR}"
           else
              FULLYEAR="19${YEAR}"
           fi
          TITLE=`$ECHO $SHORT_NAME | $AWK -F- '{print $1}'| $SED -e s/"_"/" "/g`
          REAL_SHORT="`$ECHO $SHORT_NAME|$AWK -F- '{print $1}'`"
          # get number if sides for that album
          $SED -e s/_[0-9].flac$// $LIST_SELECTION > $LIST_SELECTION_TRIMMED
          NUM_SIDES="`$GREP -xc ^\$REAL_SHORT-[0-9][0-9] $LIST_SELECTION_TRIMMED`"
          #each album is caught once per side (could add a 5 & 6 for tripple albums, but I don't have any:)
          if [ "$NUM_SIDES" -eq "4" ]; then 
             if [ "$SIDE_NUM" -eq "4" ]; then
               SIDE_4=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
               $ECHO "<tr><td>$TITLE</td><td>$FULLYEAR</td><td>$SIDE_1&nbsp;&nbsp;$SIDE_2&nbsp;&nbsp$SIDE_3&nbsp;&nbsp$SIDE_4</td></tr>" >> $LIST_FILE
              elif [ "$SIDE_NUM" -eq "3" ]; then
               SIDE_3=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
              elif [ "$SIDE_NUM" -eq "2" ]; then
               SIDE_2=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
              else
               SIDE_1=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
             fi
           elif [ "$NUM_SIDES" -eq "3" ]; then
             if [ "$SIDE_NUM" -eq "3" ]; then
               SIDE_3=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
               $ECHO "<tr><td>$TITLE</td><td>$FULLYEAR</td><td>$SIDE_1&nbsp;&nbsp$SIDE_2&nbsp;&nbsp$SIDE_3</td></tr>" >> $LIST_FILE
              elif [ "$SIDE_NUM" -eq "2" ]; then
               SIDE_2=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
              else
               SIDE_1=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
             fi
           elif [ "$NUM_SIDES" -eq "2" ]; then
             if [ "$SIDE_NUM" -eq "2" ]; then
               SIDE_2=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
               $ECHO "<tr><td>$TITLE</td><td>$FULLYEAR</td><td>$SIDE_1&nbsp;&nbsp$SIDE_2</td></tr>" >> $LIST_FILE
              else
               SIDE_1=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM </a>"`
             fi
           else
             SIDE_1=`$ECHO "<a href=$BASE_DIR/$ARTIST_NAME/$ALBUM>Side: $SIDE_NUM</a>"`
             $ECHO "<tr><td>$TITLE</td><td>$FULLYEAR</td><td>$SIDE_1</td></tr>" >> $LIST_FILE
          fi
        done < $LIST_SELECTION
     $ECHO "</td></tr>" >> $LIST_FILE
    # link to top of page
     $ECHO "<tr><td><a href=#top><font size=small>Top</font></a></td></tr>" >> $LIST_FILE
   cd $BASE_DIR
   fi
 done < $LIST_ARTISTS

$ECHO "</td></tr></table>" >> $LIST_FILE

##################################

# frame the contentas of the dir-file in html.
# you can edit the html below to customize your page


$ECHO "<html>"			>$WEB_LIST
$ECHO "<head>"			>>$WEB_LIST
$ECHO "<link rel=\"stylesheet\" type=\"text/css\" href=\"flac_jacket.css\" />"	>>$WEB_LIST
$ECHO "<title>"                 >>$WEB_LIST
$ECHO "My Album Collection" >>$WEB_LIST
$ECHO "</title>"                >>$WEB_LIST
$ECHO "</head>"                 >>$WEB_LIST
$ECHO ""			>>$WEB_LIST
$ECHO "<body>"  >>$WEB_LIST
$ECHO "<a name=top>"  		 >>$WEB_LIST
$ECHO "<img src=\"images/fjacket.png\" hspace=80 height=\"100\" align=left valign=center>"  >>$WEB_LIST
$ECHO "<h1><b>Flac-Jacket</b></h1>"  >>$WEB_LIST
$ECHO "</a>"			>>$WEB_LIST
$ECHO "<br clear=left>"			>>$WEB_LIST
$ECHO "<hr>"	>>$WEB_LIST
$ECHO "`$CAT $ARTISTS_SUMMARY`" >>$WEB_LIST
$ECHO "<br><hr>"		>>$WEB_LIST
$ECHO "<u><b><h2>Available Albums:</h2></b></u>" >>$WEB_LIST
$ECHO "`$CAT $LIST_FILE`" 	>>$WEB_LIST
$ECHO "<br><hr><br>"		>>$WEB_LIST
$ECHO "<address><font size=2><div align=right>"	>>$WEB_LIST
$ECHO "created with "		>>$WEB_LIST
$ECHO "<a href=\"http://www.linux1.ca\"> Flac-Jacket</a>"	>>$WEB_LIST
$ECHO "</div></font></address>"	>>$WEB_LIST
$ECHO "</body></html>"		>>$WEB_LIST

# end
