#!/bin/bash

# raw2flac.sh part of FLAC-JACKET - FLAC Audio Management Program
# script to convert raw audio files to flac lossless files
# created Feb 2004. Pete Nesbitt pete@linux1.ca

##
#    Copyright 2004, 2005 Pete Nesbitt (pete@linux1.ca)
#
#    This file is part of Flac-Jacket.
#
#    Flac-Jacket is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    Flac-Jacket is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with Flac-Jacket; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
##


# IMPORTANT
# raw source file name MUST be:
#  Artist_Nmae-Album_Name-yy_n.raw
#  'yy' is 2 digit year, 'n' is side (1-4)
# example: Rolling_Stones-Let_it_Bleed-69_2.raw
# Do Not use '-' or '_' anywhere else in the name.
# You can use some special characters by escaping them, but 
# your milage may very as some things may not parse correctly into the html page.
# example brackets: 
#  use Emerson_Lake_and_Palmer-Works_volume_1_\(Black\)-77_4.raw
# shows up like: Emerson_Lake_and_Palmer-Works_volume_1_(Black)-77_4.raw
# also the name is shared for all sides, so side 1 name and side 2 name must 
# be the same (except for side#), or else they will be treated as separate albums.

#  ## IMPORTANT ##
# variables are in the "flac_jacket.rc" file
# YOU MAY NEED TO EDIT THE "flac_jacket.rc" FILE:

. flac_jacket.rc

# some functions are in:
. fjacket_libs 
##############################################
NEW_ERROR="0"

# set FILES_DONE to non null
   if [ -z "$FILES_DONE" ]; then
     FILES_DONE="0"
   fi


#look thru each entry in raw dir
cd $RAW_DIR > /dev/null 2>&1
 if [ $? -ne 0 ]; then
  $ECHO ""
  $ECHO " Error!!"
  $ECHO "  Cannot access the directory containg the .raw files."
  $ECHO "  Check the $RC file for the expected location. The directory"
  $ECHO "  must exist, even if it is empty."
  exit 1
 fi

$LS -1 *.raw 1> ${TEMP}/raw_${TODAY} 2> /dev/null
FILES_TODO="`$WC -l ${TEMP}/raw_${TODAY}|$AWK '{print $1}'`"
THIS_COUNT="0"
if [ $FILES_TODO -ne 0 ]; then
 while read RAW_NAME
 do
  THIS_COUNT=`$ECHO "$THIS_COUNT + 1"| $BC`
  BASE_NAME="${RAW_NAME%%.raw}"
  ARTIST=`$ECHO $BASE_NAME|$AWK -F - '{print $1}'`
  ALBUM=`$ECHO $BASE_NAME|$AWK -F - '{print $2}'`
  SPEC=`$ECHO $BASE_NAME|$AWK -F - '{print $3}'`
  FLAC_DIR=$BASE_DIR/$ARTIST
  FLAC_NAME=$ALBUM-$SPEC.flac
  if [ -d "$FLAC_DIR" ]; then
      if [ ! -s "${FLAC_DIR}/${FLAC_NAME}" ]; then
         print_encoding
         run_flac
      else
        NEW_ERROR="1" 
        $ECHO " ** ERROR ** File $FLAC_NAME EXISTS!! ** ERROR **"
        $ECHO "  `$DATE +%Y-%m-%d-%H:%M` - ${ARTIST}-${FLAC_NAME} -Creation Failed, File exists" >> $LOG
      fi
  else
    $MKDIR $FLAC_DIR
     if [ ! -d "$FLAC_DIR" ]; then
      NEW_ERROR="1"
      $ECHO " ** ERROR ** Directory \"$FLAC_DIR\" does not exist, and cannot be created ** ERROR **"
      $ECHO "  `$DATE +%Y-%m-%d-%H:%M` - $FLAC_DIR -failed to create directory and directory does not exist" >> $LOG
     else 
      print_encoding
      run_flac
     fi
  fi
 done<${TEMP}/raw_${TODAY}
fi

## check for errors
if [ "$NEW_ERROR" != "0" ]; then
   if [ $FILES_TODO -eq 0 ]; then
    $ECHO ""
    $ECHO " No .raw source audio files found!!"
    $ECHO "  Please check the $RC file for expected location"
    exit 1
   else
    $ECHO ""
    $ECHO " THERE WERE ERRORS REPORTED!!"
    $ECHO ""
    $ECHO "  $FILES_DONE of $FILES_TODO conversions were successful"
    $ECHO "  Details are in Log File: $LOG"
    exit 1
   fi
else
    $ECHO ""
    $ECHO " All $FILES_DONE Conversions completed SUCCESSFULLY"
    $ECHO "  see $LOG for details"
fi

# end

